========
  MIGA
========
**MIGA** is a Python package that provides a MSA (Multiple Sequence Alignment) mutual information genetic algorithm optimizer. It sorts two MSAs in a way that maximize or minimize their mutual information. The genetic algorithm solvers may run on both CPU and Nvidia GPUs.

Code is hosted at GitHub_.

License
=======
This software is copyright
    * 2018 Caio Silva Souza and all contributors listed in the file AUTHORS unless stated otherwise in the source files.

MIGA is released under the LGPL software license, version 3 or later.

Contact
=======
Please report bugs and feature requests through the `Issues Tracker`_.

Documentation
=============
Plese refer to the examples_ folder in the code repository and to `online documentation`_ to learn how to use this package.

Instalation
===========
For installation instructions please refer to the `project page`_.

.. Footnotes
.. _Github: https://github.com/caioss/miga
.. _Issues Tracker: https://github.com/caioss/miga/issues
.. _examples: https://github.com/caioss/miga/tree/master/examples
.. _online documentation: https://miga.readthedocs.io
.. _project page: https://github.com/caioss/miga/blob/master/README.rst
